| Title: | Easily Install Pharmacometric Packages and Shiny Applications Developed by Certara |
|---|---|
| Description: | A convenient set of wrapper functions to install pharmacometric packages and Shiny applications developed by Certara PMX and Integrated Drug Development (iDD). The functions ensure the successful installation of packages from non-standard repositories. |
| Authors: | James Craig [aut, cre], Certara USA, Inc. [cph, fnd] |
| Maintainer: | James Craig <[email protected]> |
| License: | LGPL-3 |
| Version: | 1.1.0 |
| Built: | 2026-06-08 07:48:01 UTC |
| Source: | https://github.com/certara/r-certara |
List all packages developed by Certara
certara_packages( include_self = FALSE, include_github = TRUE, include_JFROG_deps = FALSE )certara_packages( include_self = FALSE, include_github = TRUE, include_JFROG_deps = FALSE )
include_self |
Logical; Set to |
include_github |
Logical; Set to |
include_JFROG_deps |
Logical; Set to |
Character vector of package names
certara_packages()certara_packages()
Check Certara package versions
check_certara_package_versions(pkgs)check_certara_package_versions(pkgs)
pkgs |
Character or character vector of package names. If missing, defaults to |
Named character vector indicating package version, NA is returned if Certara package is not installed
## Not run: check_certara_package_versions() ## End(Not run)## Not run: check_certara_package_versions() ## End(Not run)
Check if Certara packages are installed
check_installed_certara_packages(pkgs)check_installed_certara_packages(pkgs)
pkgs |
Character or character vector of package names. If missing, defaults to |
Named logical vector indicating whether Certara package is installed
## Not run: check_installed_certara_packages() ## End(Not run)## Not run: check_installed_certara_packages() ## End(Not run)
A user friendly wrapper to easily install R packages and Shiny applications developed by Certara
install_certara_packages( CRAN_repo = "https://cloud.r-project.org", clean_install = FALSE, quiet = FALSE )install_certara_packages( CRAN_repo = "https://cloud.r-project.org", clean_install = FALSE, quiet = FALSE )
CRAN_repo |
Character; The URL of a CRAN mirror which defaults to |
clean_install |
Logical; Set to |
quiet |
Logical; Set to |
TRUE if all packages successfully install
## Not run: install_certara_packages() ## End(Not run)## Not run: install_certara_packages() ## End(Not run)
A user friendly wrapper to easily remove R packages developed by Certara
remove_certara_packages()remove_certara_packages()
TRUE if all packages successfully removed
## Not run: remove_certara_packages() ## End(Not run)## Not run: remove_certara_packages() ## End(Not run)